@@ -25,6 +25,14 @@ our @EXPORT = qw( );
 use overload '='  => sub { $_[0]->clone() },
              'fallback' => 1;
 
+sub clone() {
+  my $self = shift;
+  my $class = ref( $self );
+  my $copy = new2( $self );
+  bless $copy, $class;
+  return $copy;
+}
+
 sub new() {
   my $class = shift;
   my $query;
