@@ -27,30 +27,17 @@ if( !$opts{d} or !$opts{t} ) {
   exit 0;
 }
 
-my $settings = Search::Xapian::Settings->new();
+my $db = Search::Xapian::Database->new( $opts{d} );
+my @terms = split ',', $opts{t};
+my $enq = $db->enquire( OP_OR, @terms );
 
-$settings->set( 'backend', 'auto' );
-$settings->set( 'auto_dir', $opts{d} );
+printf "Parsing query '%s'\n", $enq->get_query()->get_description();
 
-my $db = Search::Xapian::Database->new( $settings );
-my $enq = Search::Xapian::Enquire->new( $db );
+my @matches = $enq->matches(0, 10);
 
-my @terms = split ' ', $opts{t};
-my $query = Search::Xapian::Query->new( OP_OR, @terms );
+print scalar(@matches) . " results found\n";
 
-printf "Parsing query '%s'\n", $query->get_description();
-
-$enq->set_query( $query );
-
-my $matches = $enq->get_mset( 0, 10 );
-
-print $matches->get_matches_estimated() . " results found\n";
-
-my $match = $matches->begin();
-my $size = $matches->size();
-
-while( $size-- ){
+foreach my $match ( @matches ) {
   my $doc = $match->get_document();
   printf "ID %d %d%% [ %s ]\n", $match->get_docid(), $match->get_percent(), $doc->get_data();
-  $match->inc();
 }
